'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var core = require('@vueuse/core');
var reactivity = require('@vue/reactivity');

const _hoisted_1 = {
    id: "breakpointcompass_display",
    style: { "color": "black", "display": "flex", "flex-direction": "column", "height": "auto", "padding": "2px" }
};
const _hoisted_2 = { style: { "display": "flex", "flex-direction": "row", "justify-content": "space-evenly", "padding": "1px" } };
const _hoisted_3 = { style: { "font-size": "25px", "margin": "0", "padding": "1px" } };
const _hoisted_4 = /*#__PURE__*/ vue.createElementVNode("p", { style: { "font-size": "20px", "margin": "1px 3px" } }, "🧭", -1 /* HOISTED */);
const _hoisted_5 = { style: { "font-size": "25px", "margin": "0", "padding": "1px" } };
const _hoisted_6 = /*#__PURE__*/ vue.createElementVNode("div", { style: { "display": "flex", "flex-direction": "row", "justify-content": "space-between" } }, null, -1 /* HOISTED */);
const _hoisted_7 = {
    style: { "width": "full", "height": "30px", "padding": "0", "border-left": "2px solid red", "border-right": "2px solid red", "background-color": "lightskyblue", "position": "relative" },
    id: "breakpointcompass_progresscontainer"
};
// inject provided options
var script = /*#__PURE__*/ vue.defineComponent({
    __name: 'BreakpointCompass',
    setup(__props) {
        const injected = vue.inject("BreakpointCO");
        const el = vue.ref(null);
        const gauge = vue.ref([
            0, 15, 35, 15, 50, 15, 35, 15, 75, 15, 35, 15, 50, 15, 35, 15, 0,
        ]);
        const { width, height } = core.useWindowSize();
        const styleObject = {
            position: "fixed",
            minWidth: "150px",
            width: "auto",
            borderStyle: "solid",
            borderWidth: "2px",
            borderColor: "goldenrod",
            height: "auto",
            textAlign: "center",
            fontSize: "12px",
            fontWeight: "bold",
            backgroundColor: "gold",
            display: "flex",
            flexDirection: "column",
            borderRadius: "5px",
            cursor: "move",
        };
        const initX = injected?.position?.includes("l") ? 30 : reactivity.unref(width) - 200;
        const initY = injected?.position?.includes("t") ? 30 : reactivity.unref(height) - 80;
        const { x, y, style } = core.useDraggable(el, {
            preventDefault: true,
            initialValue: { x: initX, y: initY },
        });
        //default breakpoints in case of problem with inject ( from tailwind v3)
        const fallbackBreakPoints = [
            { name: "d-sm", px: 640 },
            { name: "d-md", px: 768 },
            { name: "d-lg", px: 1024 },
            { name: "d-xl", px: 1280 },
            { name: "d-2xl", px: 1536 },
        ];
        const loadedBreakpoints = injected?.breakpointSet || fallbackBreakPoints;
        // make sure the breakpoints are sorted from smallest to largest widths.
        const sorted = loadedBreakpoints.sort((a, b) => a.px - b.px);
        // returns current breakpoint as a string from a given width in number of pixels
        const NameFromPixels = (w) => {
            let name = "none";
            sorted.forEach(function (item) {
                if (w >= item.px) {
                    name = item.name;
                }
                if (w < item.px)
                    return item.name;
            });
            return name;
        };
        //returns the number of pixels in the next higher breakpoint from a given NameFromPixels breakpoint string
        const next = (c) => {
            // if c is the highest breakpoint return 5000 to prevent error
            if (c === sorted[sorted.length - 1].name) {
                return 5000;
            }
            return sorted[sorted.findIndex((i) => i.name === c) + 1].px || sorted[0].px;
        };
        //gives the most recent breakpoint number in pixels
        const prev = (c) => {
            if (c === "none") {
                return 0;
            }
            return sorted[sorted.findIndex((i) => i.name === c)].px || 0;
        };
        const nextBP = reactivity.computed(() => {
            return NameFromPixels(next(NameFromPixels(width.value)));
        });
        const prevBP = reactivity.computed(() => {
            return NameFromPixels(Number(prev(NameFromPixels(width.value))) - 2);
        });
        const nextPx = reactivity.computed(() => {
            return next(NameFromPixels(width.value));
        });
        const prevPx = reactivity.computed(() => {
            return prev(NameFromPixels(width.value));
        });
        const progressNext = reactivity.computed(() => {
            // check to see if current breakpoint is the highest, then return 100
            if (sorted.findIndex((i) => i.name === NameFromPixels(width.value)) >=
                sorted.length - 1) {
                return 100;
            }
            // return the percentage toward the next breakpoint
            return Math.round(((width.value - Number(prev(NameFromPixels(width.value)))) /
                (Number(next(NameFromPixels(width.value))) -
                    Number(prev(NameFromPixels(width.value))))) *
                100);
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                ref_key: "el",
                ref: el,
                id: "breakpointcompass",
                style: vue.normalizeStyle([styleObject, vue.unref(style)])
            }, [
                vue.createElementVNode("div", _hoisted_1, [
                    vue.createElementVNode("div", _hoisted_2, [
                        vue.createElementVNode("p", _hoisted_3, vue.toDisplayString(NameFromPixels(vue.unref(width))), 1 /* TEXT */),
                        _hoisted_4,
                        vue.createElementVNode("p", _hoisted_5, vue.toDisplayString(vue.unref(width)), 1 /* TEXT */)
                    ]),
                    _hoisted_6,
                    vue.createElementVNode("div", _hoisted_7, [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(gauge.value, (x, i) => {
                            return (vue.openBlock(), vue.createElementBlock("div", {
                                key: i,
                                style: vue.normalizeStyle([{ "width": "1px", "opacity": "0.5", "background-color": "#333333", "position": "absolute", "bottom": "0px" }, {
                                        left: ((i * 25) / 4).toString() + '%',
                                        height: x.toString() + '%',
                                    }])
                            }, null, 4 /* STYLE */));
                        }), 128 /* KEYED_FRAGMENT */)),
                        vue.withDirectives(vue.createElementVNode("p", { style: { "font-size": "12px", "margin": "0", "padding": "0", "color": "#333", "position": "absolute", "top": "0px", "left": "1px", "font-weight": "500" } }, " < " + vue.toDisplayString(vue.unref(prevBP)), 513 /* TEXT, NEED_PATCH */), [
                            [vue.vShow, vue.unref(prevBP) != 'none']
                        ]),
                        vue.withDirectives(vue.createElementVNode("p", { style: { "font-size": "14px", "color": "#333", "padding": "0", "position": "absolute", "bottom": "0px", "margin": "0", "left": "1px", "font-weight": "500" } }, vue.toDisplayString(vue.unref(prevPx)), 513 /* TEXT, NEED_PATCH */), [
                            [vue.vShow, vue.unref(prevPx) !== 0]
                        ]),
                        vue.withDirectives(vue.createElementVNode("p", { style: { "font-size": "12px", "color": "#333", "margin": "0", "padding": "0", "position": "absolute", "top": "0px", "right": "1px", "font-weight": "500" } }, vue.toDisplayString(vue.unref(nextBP)) + " > ", 513 /* TEXT, NEED_PATCH */), [
                            [vue.vShow, vue.unref(nextBP) != NameFromPixels(vue.unref(width))]
                        ]),
                        vue.withDirectives(vue.createElementVNode("p", { style: { "font-size": "14px", "margin": "0", "padding": "0", "color": "#333", "position": "absolute", "bottom": "0px", "right": "1px", "font-weight": "500" } }, vue.toDisplayString(vue.unref(nextPx)), 513 /* TEXT, NEED_PATCH */), [
                            [vue.vShow, vue.unref(nextBP) != NameFromPixels(vue.unref(width))]
                        ]),
                        vue.createElementVNode("div", {
                            id: "breakpointcompass_progressbar",
                            style: vue.normalizeStyle([{ "background-color": "#ff0000bb", "height": "100%", "width": "3px", "position": "absolute", "top": "0px" }, { left: vue.unref(progressNext).toString() + '%' }])
                        }, null, 4 /* STYLE */)
                    ])
                ])
            ], 4 /* STYLE */));
        };
    }
});

script.__file = "src/components/BreakpointCompass.vue";

const breakpointsTailwind = [
    { name: "sm", px: 640 },
    { name: "md", px: 768 },
    { name: "lg", px: 1024 },
    { name: "xl", px: 1280 },
    { name: "2xl", px: 1536 },
];
const breakpointsWindicss = [
    { name: "sm", px: 640 },
    { name: "md", px: 768 },
    { name: "lg", px: 1024 },
    { name: "xl", px: 1280 },
    { name: "2xl", px: 1536 },
];
const breakpointsQuasar = [
    { name: "xs", px: 0 },
    { name: "sm", px: 600 },
    { name: "md", px: 1024 },
    { name: "lg", px: 1440 },
    { name: "xl", px: 1920 },
];
const breakpointsBootstrapv3 = [
    { name: "sm", px: 576 },
    { name: "md", px: 768 },
    { name: "lg", px: 992 },
];
const breakpointsBootstrapv4 = [
    { name: "sm", px: 576 },
    { name: "md", px: 768 },
    { name: "lg", px: 992 },
    { name: "xl", px: 1200 },
];
const breakpointsBootstrapv5 = [
    { name: "sm", px: 576 },
    { name: "md", px: 768 },
    { name: "lg", px: 992 },
    { name: "xl", px: 1200 },
    { name: "xxl", px: 1400 },
];
const breakpointsBulma = [
    { name: "mobile", px: 0 },
    { name: "tablet", px: 769 },
    { name: "desktop", px: 1024 },
    { name: "widescreen", px: 1216 },
    { name: "fullhd", px: 1408 },
];
const breakpointsChakra = [
    { name: "sm", px: 480 },
    { name: "md", px: 768 },
    { name: "lg", px: 992 },
    { name: "xl", px: 1280 },
    { name: "2xl", px: 1472 },
];
const breakpointsFoundation = [
    { name: "small", px: 0 },
    { name: "medium", px: 640 },
    { name: "large", px: 1024 },
    { name: "xlarge", px: 1024 },
    { name: "xl", px: 1200 },
    { name: "xxlarge", px: 1440 },
];
const breakpointsIonic = [
    { name: "xs", px: 0 },
    { name: "sm", px: 576 },
    { name: "md", px: 768 },
    { name: "lg", px: 992 },
    { name: "xl", px: 1200 },
];
const breakpointsMaterialUI = [
    { name: "xs", px: 0 },
    { name: "sm", px: 600 },
    { name: "md", px: 960 },
    { name: "lg", px: 1280 },
    { name: "xl", px: 1920 },
];
const breakpointsMaterialize = [
    { name: "s", px: 0 },
    { name: "m", px: 600 },
    { name: "l", px: 992 },
    { name: "xl", px: 1200 },
];
const breakpointsSemanticUI = [
    { name: "mobile", px: 0 },
    { name: "tablet", px: 768 },
    { name: "small monitor", px: 992 },
    { name: "large monitor", px: 1200 },
];
const breakpointsSkeleton = [
    { name: "mobile", px: 0 },
    { name: "phablet", px: 550 },
    { name: "tablet", px: 750 },
    { name: "desktop", px: 1000 },
    { name: "desktop hd", px: 1200 },
];
const breakpointsVuetify = [
    { name: "xs", px: 0 },
    { name: "sm", px: 600 },
    { name: "md", px: 960 },
    { name: "lg", px: 1264 },
    { name: "xl", px: 1904 },
];

// Creates a new "BreakpointC" from options for use in the component via provide/inject
const createBreakpointOptions = (options) => {
    return {
        breakpointSet: options.breakpoints || breakpointsTailwind,
        position: options.position || "tr",
    };
};
//Install function used by Vue to register the plugin
const BreakpointCompassPlugin = {
    install(app, options) {
        // provide options for injection in descendant components
        app.provide("BreakpointCO", createBreakpointOptions(options || {}));
        // register compass display as a global component
        app.component("BreakpointCompass", script);
    },
};

exports.BreakpointCompass = script;
exports.BreakpointCompassPlugin = BreakpointCompassPlugin;
exports.breakpointsBootstrapv3 = breakpointsBootstrapv3;
exports.breakpointsBootstrapv4 = breakpointsBootstrapv4;
exports.breakpointsBootstrapv5 = breakpointsBootstrapv5;
exports.breakpointsBulma = breakpointsBulma;
exports.breakpointsChakra = breakpointsChakra;
exports.breakpointsFoundation = breakpointsFoundation;
exports.breakpointsIonic = breakpointsIonic;
exports.breakpointsMaterialUI = breakpointsMaterialUI;
exports.breakpointsMaterialize = breakpointsMaterialize;
exports.breakpointsQuasar = breakpointsQuasar;
exports.breakpointsSemanticUI = breakpointsSemanticUI;
exports.breakpointsSkeleton = breakpointsSkeleton;
exports.breakpointsTailwind = breakpointsTailwind;
exports.breakpointsVuetify = breakpointsVuetify;
exports.breakpointsWindicss = breakpointsWindicss;
//# sourceMappingURL=index.js.map
